Content

Enum Content 

#[non_exhaustive]
pub enum Content { Text { text: String, provider_metadata: Option<ProviderMetadata>, }, Reasoning { text: String, provider_metadata: Option<ProviderMetadata>, }, ReasoningFile { data: FileData, media_type: MediaType, provider_metadata: Option<ProviderMetadata>, }, File { data: FileData, media_type: MediaType, filename: Option<String>, provider_metadata: Option<ProviderMetadata>, }, Custom { kind: CustomKind, provider_metadata: Option<ProviderMetadata>, }, Source(Source), ToolCall(ToolCall), ToolResult(ProviderToolResult), ToolApprovalRequest { approval_id: ApprovalId, tool_call_id: ToolCallId, provider_metadata: Option<ProviderMetadata>, }, }
A content part of a generation result, tagged by type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Text

Generated text.

Fields

text: String

The text.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata.



Reasoning

Reasoning text.

Fields

text: String

The reasoning text.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata (signatures, encrypted state, …).



ReasoningFile

A reasoning artifact stored as a file.

Fields

data: FileData

File payload (inline bytes or URL).

media_type: MediaType

Media type of the payload.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata.



File

A generated file (image, audio, …).

Fields

data: FileData

File payload (inline bytes or URL).

media_type: MediaType

Media type of the payload.

filename: Option<String>

Optional file name.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata.



Custom

Provider-specific content identified by a provider.type kind.

Fields

kind: CustomKind

Kind of the content.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata carrying the payload.



Source(Source)

A citation source.



ToolCall(ToolCall)

A tool call requested by the model.



ToolResult(ProviderToolResult)

The result of a provider-executed tool.



ToolApprovalRequest

The provider asks for approval before executing a tool call.

Fields

approval_id: ApprovalId

Identifier of the approval request.

tool_call_id: ToolCallId

Identifier of the tool call awaiting approval.

provider_metadata: Option<ProviderMetadata>

Provider-specific metadata.

Implementations

Source

impl Content

pub fn text(text: impl Into<String>) -> Self

Creates a text part without metadata.

pub fn reasoning(text: impl Into<String>) -> Self

Creates a reasoning part without metadata.

pub fn as_text(&self) -> Option<&str>

Returns the text of a Content::Text part.

pub fn as_tool_call(&self) -> Option<&ToolCall>

Returns the tool call of a Content::ToolCall part.

pub fn kind_name(&self) -> &'static str

Returns the wire name of the variant (text, tool-call, …).