pub struct ProviderToolResult {
pub tool_call_id: ToolCallId,
pub tool_name: ToolName,
pub result: JsonValue,
pub is_error: bool,
pub preliminary: bool,
pub dynamic: bool,
pub provider_metadata: Option<ProviderMetadata>,
}Expand description
The result of a tool executed by the provider.
Fields
tool_call_id: ToolCallIdIdentifier of the tool call.
tool_name: ToolNameName of the tool.
result: JsonValueThe result value.
is_error: boolWhether the result is an error.
preliminary: boolWhether this is a preliminary result that will be superseded.
dynamic: boolWhether the tool is dynamic.
provider_metadata: Option<ProviderMetadata>Provider-specific metadata.