#[non_exhaustive]pub enum PromptMessage {
System {
content: String,
provider_options: Option<ProviderOptions>,
},
User {
content: Vec<UserPromptPart>,
provider_options: Option<ProviderOptions>,
},
Assistant {
content: Vec<AssistantPromptPart>,
provider_options: Option<ProviderOptions>,
},
Tool {
content: Vec<ToolPromptPart>,
provider_options: Option<ProviderOptions>,
},
}Expand description
A message in a specification prompt, tagged by role.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
System
System instructions.
Fields

provider_options: Option<ProviderOptions>Provider-specific options for this message.
User
User input.
Fields

content: Vec<UserPromptPart>Text and file parts.

provider_options: Option<ProviderOptions>Provider-specific options for this message.
Assistant
Previous assistant output.
Fields

content: Vec<AssistantPromptPart>Assistant parts, including tool calls and provider-executed results.

provider_options: Option<ProviderOptions>Provider-specific options for this message.
Tool
Tool results and approval responses.
Fields

content: Vec<ToolPromptPart>Tool parts.

provider_options: Option<ProviderOptions>Provider-specific options for this message.
Implementations
Sourceimpl PromptMessage
impl PromptMessage
Sourcepub fn user_text(text: impl Into<String>) -> Self
pub fn user_text(text: impl Into<String>) -> Self
Creates a user message with a single text part.
Sourcepub fn user(content: Vec<UserPromptPart>) -> Self
pub fn user(content: Vec<UserPromptPart>) -> Self
Creates a user message from parts.
Sourcepub fn assistant_text(text: impl Into<String>) -> Self
pub fn assistant_text(text: impl Into<String>) -> Self
Creates an assistant message with a single text part.
Sourcepub fn assistant(content: Vec<AssistantPromptPart>) -> Self
pub fn assistant(content: Vec<AssistantPromptPart>) -> Self
Creates an assistant message from parts.
Sourcepub fn tool(content: Vec<ToolPromptPart>) -> Self
pub fn tool(content: Vec<ToolPromptPart>) -> Self
Creates a tool message from parts.
Sourcepub fn provider_options(&self) -> Option<&ProviderOptions>
pub fn provider_options(&self) -> Option<&ProviderOptions>
Returns the provider options attached to the message.