pub struct ResponseMetadata {
pub id: Option<String>,
pub timestamp: Option<DateTime<Utc>>,
pub model_id: Option<ModelId>,
pub headers: Option<Headers>,
pub body: Option<JsonValue>,
}Expand description
Metadata about the provider response.
Every field is optional because it may be unknown at the point where the metadata is created (for example headers-only metadata at stream start).
Fields
id: Option<String>Provider response id.
timestamp: Option<DateTime<Utc>>Response timestamp.
model_id: Option<ModelId>Model that produced the response (may differ from the requested id).
headers: Option<Headers>Response headers.
body: Option<JsonValue>Raw response body (non-streaming calls).
Implementations
Sourceimpl ResponseMetadata
impl ResponseMetadata
Sourcepub fn with_headers(headers: Headers) -> Self
pub fn with_headers(headers: Headers) -> Self
Creates metadata that only carries headers.
Sourcepub fn new(timestamp: DateTime<Utc>, model_id: impl Into<ModelId>) -> Self
pub fn new(timestamp: DateTime<Utc>, model_id: impl Into<ModelId>) -> Self
Creates metadata with timestamp and model id, as required by non-text modalities.
Sourcepub fn merge(&mut self, other: ResponseMetadata)
pub fn merge(&mut self, other: ResponseMetadata)
Overlays fields that are Some in other onto self.