#[non_exhaustive]pub enum ToolDefinition {
Function {
name: ToolName,
description: Option<String>,
input_schema: JsonValue,
strict: Option<bool>,
input_examples: Vec<JsonObject>,
provider_options: Option<ProviderOptions>,
},
Provider {
id: String,
name: ToolName,
args: JsonObject,
},
}Expand description
A tool made available to the model.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Function
A function tool executed by the application (or by the provider when
it reports provider_executed).
Fields

input_examples: Vec<JsonObject>Example inputs.

provider_options: Option<ProviderOptions>Provider-specific options for this tool.
Provider
A tool defined and executed by the provider (web search, code interpreter, …).
Implementations
Sourceimpl ToolDefinition
impl ToolDefinition
Sourcepub fn function(
name: impl Into<ToolName>,
description: Option<String>,
input_schema: JsonValue,
) -> Self
pub fn function( name: impl Into<ToolName>, description: Option<String>, input_schema: JsonValue, ) -> Self
Creates a function tool with a schema and optional description.
Sourcepub fn provider(
id: impl Into<String>,
name: impl Into<ToolName>,
args: JsonObject,
) -> Self
pub fn provider( id: impl Into<String>, name: impl Into<ToolName>, args: JsonObject, ) -> Self
Creates a provider tool.
Sourcepub fn is_provider_tool(&self) -> bool
pub fn is_provider_tool(&self) -> bool
Returns true for ToolDefinition::Provider.